Align Example
===============================================================================

:download:`align.enaml <../../../examples/layout/basic/align.enaml>`

.. literalinclude:: ../../../examples/layout/basic/align.enaml
    :language: python

::

 $ enaml-run align.enaml

.. image:: images/align.png
